package com.ruoyi.rocketmq.service;

import com.ruoyi.rocketmq.domain.InitialMemoryInfo;

import java.util.List;
import java.util.Map;

/**
 * 内存监控信息Service接口
 * 
 * @author gyt
 * @date 2025-08-25
 */
public interface IInitialMemoryInfoService 
{
    /**
     * 查询内存监控信息
     * 
     * @param id 内存监控信息主键
     * @return 内存监控信息
     */
    public InitialMemoryInfo selectInitialMemoryInfoById(Long id);

    /**
     * 查询内存监控信息列表
     * 
     * @param initialMemoryInfo 内存监控信息
     * @return 内存监控信息集合
     */
    public List<InitialMemoryInfo> selectInitialMemoryInfoList(InitialMemoryInfo initialMemoryInfo);

    /**
     * 新增内存监控信息
     * 
     * @param initialMemoryInfo 内存监控信息
     * @return 结果
     */
    public int insertInitialMemoryInfo(InitialMemoryInfo initialMemoryInfo);

    /**
     * 修改内存监控信息
     * 
     * @param initialMemoryInfo 内存监控信息
     * @return 结果
     */
    public int updateInitialMemoryInfo(InitialMemoryInfo initialMemoryInfo);

    /**
     * 批量删除内存监控信息
     * 
     * @param ids 需要删除的内存监控信息主键集合
     * @return 结果
     */
    public int deleteInitialMemoryInfoByIds(Long[] ids);

    /**
     * 删除内存监控信息信息
     * 
     * @param id 内存监控信息主键
     * @return 结果
     */
    public int deleteInitialMemoryInfoById(Long id);
    /**
     * 批量新增内存监控信息
     *
     * @param list 内存监控信息集合
     * @return 结果
     */
    public int batchInsertInitialMemoryInfo(List<InitialMemoryInfo> list);

    /**
     * 内存信息echarts图
     * @param initialMemoryInfo
     * @return
     */
    Map<String, Object> swapSizeFreeEcharts(InitialMemoryInfo initialMemoryInfo);
    /**
     * 查询内存利用率监控数据
     */
    Map<String, Object> untilzationEcharts(InitialMemoryInfo initialMemoryInfo);
    /**
     * 查询内存可用量监控数据（KB）
     */
    Map<String, Object> availableMemoryEcharts(InitialMemoryInfo initialMemoryInfo);
    /**
     * 查询交换空间百分比监控数据
     */
    Map<String, Object> swapSizePercentEcharts(InitialMemoryInfo initialMemoryInfo);
    /**
     * 查询可用内存百分比监控数据
     */
    Map<String, Object> percentEcharts(InitialMemoryInfo initialMemoryInfo);
}
